pub(crate) enum SuggestionError {
InvalidRange {
range: StringRange,
input_length: usize,
},
NonEncompassingRange {
outer: StringRange,
inner: StringRange,
},
}Expand description
A suggestion range could not be mapped to valid UTF-8 boundaries.
Variants
InvalidRange
The UTF-16 range is out of bounds or splits a supplementary character.
NonEncompassingRange
An expansion range does not contain the original suggestion range.