pub(crate) struct Suggestions {
range: StringRange,
suggestions: Vec<Suggestion>,
}Expand description
A sorted set of command completions sharing one replacement range.
Fields
range: StringRangesuggestions: Vec<Suggestion>Implementations
Sourceimpl Suggestions
impl Suggestions
Sourcepub(crate) const fn new(
range: StringRange,
suggestions: Vec<Suggestion>,
) -> Self
pub(crate) const fn new( range: StringRange, suggestions: Vec<Suggestion>, ) -> Self
Creates suggestions that already share one range.
Sourcepub(crate) const fn range(&self) -> StringRange
pub(crate) const fn range(&self) -> StringRange
Returns the common replacement range.
Sourcepub(crate) fn list(&self) -> &[Suggestion]
pub(crate) fn list(&self) -> &[Suggestion]
Returns the sorted suggestions.
Sourcepub(crate) fn merge(
input: &str,
suggestions: Vec<Self>,
) -> Result<Self, SuggestionError>
pub(crate) fn merge( input: &str, suggestions: Vec<Self>, ) -> Result<Self, SuggestionError>
Merges multiple suggestion sets and expands them to one range.
fn create( input: &str, suggestions: Vec<Suggestion>, ) -> Result<Self, SuggestionError>
fn compare_suggestions(first: &Suggestion, second: &Suggestion) -> Ordering