SuggestionsBuilder

Struct SuggestionsBuilder 

pub(crate) struct SuggestionsBuilder<'input> {
    input: &'input str,
    start: usize,
    byte_start: usize,
    remaining_lowercase: String,
    suggestions: Vec<Suggestion>,
}
Accumulates suggestions for one input suffix.

Fields

input: &'input strstart: usizebyte_start: usizeremaining_lowercase: Stringsuggestions: Vec<Suggestion>

Implementations

Source

impl<'input> SuggestionsBuilder<'input>

pub(crate) fn new( input: &'input str, start: usize, ) -> Result<Self, SuggestionError>

Creates a builder at a UTF-16 input position.

pub(crate) const fn input(&self) -> &'input str

Returns the complete input.

pub(crate) const fn start(&self) -> usize

Returns the UTF-16 replacement start.

pub(crate) fn remaining(&self) -> &'input str

Returns the suffix being replaced.

pub(crate) fn remaining_lowercase(&self) -> &str

Returns a lowercase copy of the suffix being replaced.

pub(crate) fn suggest(&mut self, text: impl Into<Box<str>>) -> &mut Self

Adds a textual suggestion unless it is already the exact suffix.

pub(crate) fn suggest_with_tooltip( &mut self, text: impl Into<Box<str>>, tooltip: impl Into<TextComponent>, ) -> &mut Self

Adds a textual suggestion with a tooltip.

pub(crate) fn suggest_integer(&mut self, value: i32) -> &mut Self

Adds an integer suggestion.

pub(crate) fn build(self) -> Result<Suggestions, SuggestionError>

Builds, deduplicates, and sorts the accumulated suggestions.

pub(crate) fn restart(&self) -> Result<Self, SuggestionError>

Creates an empty builder with the same input and start.

fn range(&self) -> StringRange