pub(crate) struct SuggestionsBuilder<'input> {
input: &'input str,
start: usize,
byte_start: usize,
remaining_lowercase: String,
suggestions: Vec<Suggestion>,
}Expand description
Accumulates suggestions for one input suffix.
Fields
input: &'input strstart: usizebyte_start: usizeremaining_lowercase: Stringsuggestions: Vec<Suggestion>Implementations
Sourceimpl<'input> SuggestionsBuilder<'input>
impl<'input> SuggestionsBuilder<'input>
Sourcepub(crate) fn new(
input: &'input str,
start: usize,
) -> Result<Self, SuggestionError>
pub(crate) fn new( input: &'input str, start: usize, ) -> Result<Self, SuggestionError>
Creates a builder at a UTF-16 input position.
Sourcepub(crate) fn remaining_lowercase(&self) -> &str
pub(crate) fn remaining_lowercase(&self) -> &str
Returns a lowercase copy of the suffix being replaced.
Sourcepub(crate) fn suggest(&mut self, text: impl Into<Box<str>>) -> &mut Self
pub(crate) fn suggest(&mut self, text: impl Into<Box<str>>) -> &mut Self
Adds a textual suggestion unless it is already the exact suffix.
Sourcepub(crate) fn suggest_with_tooltip(
&mut self,
text: impl Into<Box<str>>,
tooltip: impl Into<TextComponent>,
) -> &mut Self
pub(crate) fn suggest_with_tooltip( &mut self, text: impl Into<Box<str>>, tooltip: impl Into<TextComponent>, ) -> &mut Self
Adds a textual suggestion with a tooltip.
Sourcepub(crate) fn suggest_integer(&mut self, value: i32) -> &mut Self
pub(crate) fn suggest_integer(&mut self, value: i32) -> &mut Self
Adds an integer suggestion.
Sourcepub(crate) fn build(self) -> Result<Suggestions, SuggestionError>
pub(crate) fn build(self) -> Result<Suggestions, SuggestionError>
Builds, deduplicates, and sorts the accumulated suggestions.
Sourcepub(crate) fn restart(&self) -> Result<Self, SuggestionError>
pub(crate) fn restart(&self) -> Result<Self, SuggestionError>
Creates an empty builder with the same input and start.
fn range(&self) -> StringRange